advertools.stopwords module — advertools 0.1a1 documentation

# advertools.stopwords module

List of stopwords useful in text mining, analyzing content of tweets, web pages, keywords, etc.

Each list is accessible as part of a dictionary stopwords which is a normal Python dictionary.

## Examples

    >>> import advertools as adv
    >>> adv.stopwords['english'][:5]
    ['i', 'me', 'my', 'myself', 'we']
    >>> adv.stopwords['german'][:5]
    ['aber', 'alle', 'allem', 'allen', 'aller']